==> haskell-connection-0.3.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.3.0
id: connection-0.3.0-LFpwhe0plnx8ZsN0Tj576u
key: connection-0.3.0-LFpwhe0plnx8ZsN0Tj576u
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
abi: 946cc8532378af7bd428e69219e16893
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/connection-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/connection-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/connection-0.3.0
hs-libraries: HSconnection-0.3.0-LFpwhe0plnx8ZsN0Tj576u
depends:
    base-4.12.0.0 basement-0.0.10-2z2JaOuy7fVLQL3Bi1dEbr
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    network-2.8.0.0-EWiez0ajBalJ2cORFP4yEt
    socks-0.6.0-LfWiqk5w7L32Hg58ovKPWE tls-1.4.1-UtXELbmKRkISZfsPdmvB8
    x509-1.7.5-4SipZUEfLKoGzZKIMuaQ6w
    x509-store-1.6.7-KIqe5sij70W6buPBlQvxx7
    x509-system-1.6.6-2xMOs9s4qOg8DrM2oQb7fW
    x509-validation-1.6.11-B4XHiOnvZY59GNnl3eOH5e
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-connection-0.3.0-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.3.0
id: connection-0.3.0-9QMlEAr3Jzc4SKjOGul0PD
key: connection-0.3.0-9QMlEAr3Jzc4SKjOGul0PD
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
abi: 1d67a7e620079e0e8146d80773848a63
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/connection-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/connection-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/connection-0.3.0
hs-libraries: HSconnection-0.3.0-9QMlEAr3Jzc4SKjOGul0PD
depends:
    base-4.12.0.0 basement-0.0.10-2z2JaOuy7fVLQL3Bi1dEbr
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    network-2.8.0.0-FZwMvc7MoUJBpGGHu2O13h
    socks-0.6.0-IrctS26XgD5FJrSmrupJN8 tls-1.4.1-D1Lz3eNVcZmFzWatY6XhBG
    x509-1.7.5-D34VBrGW3i7B6Eu45oEieF
    x509-store-1.6.7-3NApxTvogOMEihOVBqSlKH
    x509-system-1.6.6-9lR8tGFP4ZGJK7ZXYxmfVf
    x509-validation-1.6.11-50IKP4foIhqI6cjbporGYR
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
